@@ -6,7 +6,10 @@ import requests
 from cryptography import x509
 from cryptography.hazmat.primitives import hashes, serialization
 import base64
-from urlparse import urljoin
+try:
+    from urllib.parse import urljoin
+except ImportError:
+    from urlparse import urljoin
 import logging
 
 CRL_FILE_NAME = "db.crl"
@@ -219,7 +222,7 @@ class OCSPResponder(object):
         :param str certificate_path: path to certificate path
         :return: a cryptography.x509.Certificate
         """
-        with open(certificate_path, 'rt') as cert_file:
+        with open(certificate_path, 'rb') as cert_file:
             cert_str = cert_file.read()
         return x509.load_pem_x509_certificate(cert_str)
 
